<?php
/**
 * Plugin Name: Easy Contact Popup
 * Plugin URI: https://joevics.pro/easy-contact-popup
 * Description: Add a beautiful, customizable contact form popup to your WordPress menu with email notifications and submission tracking.
 * Version: 3.0.0
 * Requires at least: 5.2
 * Requires PHP: 7.4
 * Author: Victor Joshua
 * Author URI: https://joevics.pro
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: easy-contact-popup
 * Domain Path: /languages
 *
 * @package EasyContactPopup
 */

// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Define plugin constants
define('ECP_VERSION', '1.0.0');
define('ECP_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('ECP_PLUGIN_URL', plugin_dir_url(__FILE__));

// Load plugin textdomain
add_action('plugins_loaded', 'ecp_load_textdomain');
function ecp_load_textdomain() {
    load_plugin_textdomain('easy-contact-popup', false, dirname(plugin_basename(__FILE__)) . '/languages');
}

class EasyContactPopup {
    private static $instance = null;

    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct() {
    $this->verify_submissions_table();
        // Create database table on plugin activation
        
    global $wpdb;
    $table_name = $wpdb->prefix . 'contact_submissions';
    $table_exists = $wpdb->get_var("SHOW TABLES LIKE '$table_name'") === $table_name;
    
    if (!$table_exists) {
        contact_popup_create_table();
    }
    
    // Add hooks only if we're not in admin
    if (!is_admin()) {
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));
        add_action('wp_footer', array($this, 'add_popup_html'));
    }

    if (is_admin()) {
        add_action('admin_menu', array($this, 'add_admin_pages'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_init', array($this, 'add_donation_reminder'));
    }


    // These hooks work in admin
    add_filter('wp_nav_menu_objects', array($this, 'add_popup_trigger_class'), 10, 1);
    add_action('wp_nav_menu_item_custom_fields', array($this, 'popup_trigger_field_html'), 10, 4);
    add_action('wp_update_nav_menu_item', array($this, 'update_popup_trigger_field'), 10, 3);
    
    // Ajax handlers
    add_action('wp_ajax_easy_contact_submit', array($this, 'handle_form_submission'));
    add_action('wp_ajax_nopriv_easy_contact_submit', array($this, 'handle_form_submission'));
}

    public function enqueue_scripts() {
        // Enqueue styles
        wp_enqueue_style(
            'easy-contact-popup',
            plugin_dir_url(__FILE__) . 'assets/css/popup.css',
            array(),
            '1.0.0'
        );

        // Enqueue scripts
        wp_enqueue_script(
            'easy-contact-popup',
            plugin_dir_url(__FILE__) . 'assets/js/popup.js',
            array('jquery'),
            '1.0.0',
            true
        );

        // Localize script
        wp_localize_script(
            'easy-contact-popup',
            'easyContactPopup',
            array(
                'ajaxurl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('easy_contact_popup_nonce')
            )
        );
    }

public function add_popup_html() {
    $options = get_option('contact_popup_settings', array());
    $primary_color = !empty($options['primary_color']) ? $options['primary_color'] : '#0073aa';
    $button_color = !empty($options['button_color']) ? $options['button_color'] : '#0073aa';
?>
<div id="easy-contact-popup" style="display: none;" data-success-color="<?php echo esc_attr($success_color); ?>">
            <div class="popup-overlay">
                <div class="popup-content">
                    <span class="popup-close">&times;</span>
                    <h2 style="color: <?php echo esc_attr($primary_color); ?>">
                        <?php echo esc_html(!empty($options['form_title']) ? $options['form_title'] : 'Contact Us'); ?>
                    </h2>
                    <p class="popup-description">
                        <?php echo esc_html(!empty($options['form_description']) ? $options['form_description'] : "We'd love to hear from you! Send us a message."); ?>
                    </p>
                    <form id="easy-contact-form">
                        <?php wp_nonce_field('easy_contact_popup_nonce', 'contact_nonce'); ?>
                        <div class="form-group">
                            <input type="text" name="name" 
                                placeholder="<?php echo esc_attr(!empty($options['name_placeholder']) ? $options['name_placeholder'] : 'Your Name'); ?>" 
                                required>
                        </div>
                        <div class="form-group">
                            <input type="email" name="email" 
                                placeholder="<?php echo esc_attr(!empty($options['email_placeholder']) ? $options['email_placeholder'] : 'Your Email'); ?>" 
                                required>
                        </div>
                        <div class="form-group">
                            <textarea name="message" 
                                placeholder="<?php echo esc_attr(!empty($options['message_placeholder']) ? $options['message_placeholder'] : 'Your Message'); ?>" 
                                required></textarea>
                        </div>
                        <button type="submit" style="background-color: <?php echo esc_attr($button_color); ?>">
                            <?php echo esc_html(!empty($options['submit_text']) ? $options['submit_text'] : 'Send Message'); ?>
                        </button>
                    </form>
                </div>
            </div>
        </div>
        <?php
    }

public function handle_form_submission() {
    try {
        error_log('Form submission started');
        
        // Verify nonce
        check_ajax_referer('easy_contact_popup_nonce', 'nonce');

        // Validate inputs
        if (empty($_POST['name']) || empty($_POST['email']) || empty($_POST['message'])) {
            wp_send_json_error(array('message' => 'All fields are required.'));
            return;
        }

        $name = sanitize_text_field($_POST['name']);
        $email = sanitize_email($_POST['email']);
        $message = sanitize_textarea_field($_POST['message']);

        if (!is_email($email)) {
            wp_send_json_error(array('message' => 'Invalid email address.'));
            return;
        }

        // Get settings
        $options = get_option('contact_popup_settings', array());
                $success_color = !empty($options['success_color']) ? $options['success_color'] : '#4CAF50';
        
        // Store in database
        global $wpdb;
        $table_name = $wpdb->prefix . 'contact_submissions';
        
        $inserted = $wpdb->insert(
            $table_name,
            array(
                'name' => $name,
                'email' => $email,
                'message' => $message,
                'date' => current_time('mysql')
            ),
            array('%s', '%s', '%s', '%s')
        );

        if ($inserted === false) {
            error_log('Contact Form DB Error: ' . $wpdb->last_error);
            throw new Exception('Failed to save submission.');
        }

        // Send email notification
        $to = !empty($options['notification_email']) ? $options['notification_email'] : get_option('admin_email');
        $subject = 'New Contact Form Submission';
        $email_message = "You have received a new contact form submission:\n\n";
        $email_message .= "Name: " . $name . "\n";
        $email_message .= "Email: " . $email . "\n";
        $email_message .= "Message: " . $message . "\n\n";
        $email_message .= "Sent from: " . get_bloginfo('name') . " (" . get_site_url() . ")";

        $headers = array(
            'Content-Type: text/plain; charset=UTF-8',
            'From: ' . get_bloginfo('name') . ' <' . get_option('admin_email') . '>',
            'Reply-To: ' . $name . ' <' . $email . '>'
        );

        $email_sent = wp_mail($to, $subject, $email_message, $headers);
        
        if (!$email_sent) {
            error_log('Contact Form Email Error - Failed to send email to: ' . $to);
            error_log('Contact Form Email Details - Subject: ' . $subject);
            error_log('Contact Form Email Details - Headers: ' . print_r($headers, true));
            
            // Check if wp_mail is functioning
            global $phpmailer;
            if (isset($phpmailer->ErrorInfo)) {
                error_log('Contact Form PHPMailer Error: ' . $phpmailer->ErrorInfo);
            }
        }

        // Get success message from settings or use default
        $success_message = !empty($options['success_message']) 
            ? $options['success_message'] 
            : 'Thank you! Your message has been sent successfully.';


        wp_send_json_success(array(
            'message' => $success_message,
            'success_color' => $success_color  // Add this line
        ));

    } catch (Exception $e) {
        error_log('Contact Form Error: ' . $e->getMessage());
        wp_send_json_error(array(
            'message' => 'An error occurred. Please try again.'
        ));
    }
}

    public function popup_trigger_field_html($item_id, $item, $depth, $args) {
        $trigger_popup = get_post_meta($item_id, '_menu_trigger_popup', true);
        ?>
        <p class="field-trigger-popup description-wide">
            <label for="edit-menu-trigger-popup-<?php echo esc_attr($item_id); ?>">
                <input type="checkbox" 
                       id="edit-menu-trigger-popup-<?php echo esc_attr($item_id); ?>" 
                       value="1" 
                       name="menu_trigger_popup[<?php echo esc_attr($item_id); ?>]"
                       <?php checked($trigger_popup, '1'); ?>>
                Make this a contact form popup trigger
            </label>
        </p>
        <?php
    }

    public function update_popup_trigger_field($menu_id, $menu_item_id) {
        if (isset($_POST['menu_trigger_popup'][$menu_item_id])) {
            update_post_meta($menu_item_id, '_menu_trigger_popup', '1');
        } else {
            delete_post_meta($menu_item_id, '_menu_trigger_popup');
        }
    }

public function verify_submissions_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'contact_submissions';
    
    $table_exists = $wpdb->get_var("SHOW TABLES LIKE '$table_name'") === $table_name;
    error_log('Checking if table exists: ' . ($table_exists ? 'yes' : 'no'));
    
    if (!$table_exists) {
        error_log('Creating submissions table');
        contact_popup_create_table();
    }
}

    public function add_popup_trigger_class($menu_items) {
        foreach ($menu_items as $menu_item) {
            if (get_post_meta($menu_item->ID, '_menu_trigger_popup', true)) {
                $menu_item->classes[] = 'easy-contact-trigger';
                $menu_item->url = '#contact';
            }
        }
        return $menu_items;
    }

    public function add_admin_pages() {
        add_menu_page(
            'Contact Popup',
            'Contact Popup',
            'manage_options',
            'contact-popup-settings',
            array($this, 'render_settings_page'),
            'dashicons-email',
            30
        );

        add_submenu_page(
            'contact-popup-settings',
            'Settings',
            'Settings',
            'manage_options',
            'contact-popup-settings',
            array($this, 'render_settings_page')
        );

        add_submenu_page(
            'contact-popup-settings',
            'Submissions',
            'Submissions',
            'manage_options',
            'contact-popup-submissions',
            array($this, 'render_submissions_page')
        );

        add_submenu_page(
            'contact-popup-settings',
            'Help',
            'Help',
            'manage_options',
            'contact-popup-help',
            array($this, 'render_help_page')
        );

        add_submenu_page(
            'contact-popup-settings',
            'Donate',
            'Donate',
            'manage_options',
            'contact-popup-donate',
            array($this, 'render_donate_page')
        );
    }

    public function register_settings() {
        register_setting('contact_popup_options', 'contact_popup_settings');
        
        $sections = array(
            'appearance' => 'Appearance Settings',
            'text' => 'Text Settings',
            'email' => 'Email Settings'
        );

        foreach ($sections as $section_id => $title) {
            add_settings_section(
                'contact_popup_' . $section_id,
                $title,
                null,
                'contact-popup-settings'
            );
        }

        $this->add_settings_fields();
    }

    private function add_settings_fields() {
        $fields = array(
            'appearance' => array(
                'primary_color' => array(
                    'label' => 'Primary Color',
                    'type' => 'color',
                    'default' => '#0073aa'
                ),
                'button_color' => array(
                    'label' => 'Button Color',
                    'type' => 'color',
                    'default' => '#0073aa'
            ),
            'success_color' => array(
                'label' => 'Success Message Color',
                'type' => 'color',
                'default' => '#4CAF50'
                )
            ),
            'text' => array(
                'form_title' => array(
                    'label' => 'Form Title',
                    'type' => 'text',
                    'default' => 'Contact Us'
                ),
                'form_description' => array(
                    'label' => 'Form Description',
                    'type' => 'textarea',
                    'default' => "We'd love to hear from you! Send us a message."
                ),
                'success_message' => array(
                    'label' => 'Success Message',
                    'type' => 'textarea',
                    'default' => 'Thank you! Your message has been sent successfully.'
                )
            ),
            'email' => array(
                'notification_email' => array(
                    'label' => 'Notification Email',
                    'type' => 'email',
                    'default' => get_option('admin_email')
                )
            )
        );

        foreach ($fields as $section => $section_fields) {
            foreach ($section_fields as $field_id => $field_data) {
                add_settings_field(
                    $field_id,
                    $field_data['label'],
                    array($this, 'render_field'),
                    'contact-popup-settings',
                    'contact_popup_' . $section,
                    array(
                        'field_id' => $field_id,
                        'type' => $field_data['type'],
                        'default' => $field_data['default']
                    )
                );
            }
        }
    }

    public function render_field($args) {
        $options = get_option('contact_popup_settings', array());
        $field_id = $args['field_id'];
        $type = $args['type'];
        $value = isset($options[$field_id]) ? $options[$field_id] : $args['default'];

        switch ($type) {
            case 'color':
                printf(
                    '<input type="color" id="%s" name="contact_popup_settings[%s]" value="%s">',
                    esc_attr($field_id),
                    esc_attr($field_id),
                    esc_attr($value)
                );
                break;

            case 'textarea':
                printf(
                    '<textarea id="%s" name="contact_popup_settings[%s]" rows="3" class="large-text">%s</textarea>',
                    esc_attr($field_id),
                    esc_attr($field_id),
                    esc_textarea($value)
                );
                break;

            default:
                printf(
                    '<input type="%s" id="%s" name="contact_popup_settings[%s]" value="%s" class="regular-text">',
                    esc_attr($type),
                    esc_attr($field_id),
                    esc_attr($field_id),
                    esc_attr($value)
                );
        }
    }

    public function render_settings_page() {
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <form action="options.php" method="post">
                <?php
                settings_fields('contact_popup_options');
                do_settings_sections('contact-popup-settings');
                submit_button('Save Settings');
                ?>
            </form>
        </div>
        <?php
    }

    public function render_submissions_page() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'contact_submissions';

        // Handle bulk delete
        if (isset($_POST['action']) && $_POST['action'] === 'delete' && isset($_POST['submissions'])) {
            check_admin_referer('bulk-submissions');
            
            $ids = array_map('intval', $_POST['submissions']);
            foreach ($ids as $id) {
                $wpdb->delete($table_name, array('id' => $id), array('%d'));
            }
            echo '<div class="notice notice-success"><p>Selected submissions deleted.</p></div>';
        }

        // Get submissions with pagination
        $page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
        $per_page = 20;
        $offset = ($page - 1) * $per_page;

        $total_items = $wpdb->get_var("SELECT COUNT(id) FROM $table_name");
        $submissions = $wpdb->get_results($wpdb->prepare(
            "SELECT * FROM $table_name ORDER BY date DESC LIMIT %d OFFSET %d",
            $per_page,
            $offset
        ));

        ?>
        <div class="wrap contact-popup-admin">
            <h1 class="wp-heading-inline">Form Submissions</h1>
            
            <?php if (empty($submissions)): ?>
                <div class="card">
                    <p>No submissions yet.</p>
                </div>
            <?php else: ?>
                <form method="post">
                    <?php wp_nonce_field('bulk-submissions'); ?>
                    <div class="tablenav top">
                        <div class="alignleft actions bulkactions">
                            <label for="bulk-action-selector-top" class="screen-reader-text">Select bulk action</label>
                            <select name="action" id="bulk-action-selector-top">
                                <option value="-1">Bulk Actions</option>
                                <option value="delete">Delete</option>
                            </select>
                            <input type="submit" class="button action" value="Apply">
                        </div>
                        <div class="tablenav-pages">
                            <?php
                            $total_pages = ceil($total_items / $per_page);
                            if ($total_pages > 1) {
                                echo paginate_links(array(
                                    'base' => add_query_arg('paged', '%#%'),
                                    'format' => '',
                                    'prev_text' => __('&laquo;'),
                                    'next_text' => __('&raquo;'),
                                    'total' => $total_pages,
                                    'current' => $page
                                ));
                            }
                            ?>
                        </div>
                    </div>

                    <table class="wp-list-table widefat fixed striped submissions-table">
                        <thead>
                            <tr>
                                <td class="manage-column column-cb check-column">
                                    <input type="checkbox" id="cb-select-all-1">
                                </td>
                                <th scope="col" class="manage-column column-date">Date</th>
                                <th scope="col" class="manage-column column-name">Name</th>
                                <th scope="col" class="manage-column column-email">Email</th>
                                <th scope="col" class="manage-column column-message">Message</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($submissions as $submission): ?>
                                <tr>
                                    <th scope="row" class="check-column">
                                        <input type="checkbox" name="submissions[]" value="<?php echo esc_attr($submission->id); ?>">
                                    </th>
                                    <td class="column-date">
                                        <?php echo esc_html(wp_date('Y-m-d H:i:s', strtotime($submission->date))); ?>
                                    </td>
                                    <td class="column-name"><?php echo esc_html($submission->name); ?></td>
                                    <td class="column-email"><?php echo esc_html($submission->email); ?></td>
                                    <td class="column-message"><?php echo esc_html($submission->message); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </form>
            <?php endif; ?>
        </div>
        <?php
    }

public function render_help_page() {
    ?>
    <div class="wrap">
        <h1>Help & Documentation</h1>
        
        <div class="card">
            <h2>Quick Start Guide</h2>
            <ol>
                <li><strong>Adding the Contact Form to Menu:</strong>
                    <ul>
                        <li>Go to Appearance → Menus</li>
                        <li>Edit any menu item</li>
                        <li>Check the "Make this a contact form popup trigger" option</li>
                        <li>Save the menu</li>
                    </ul>
                </li>
                <li><strong>Customizing the Form:</strong>
                    <ul>
                        <li>Go to Contact Popup → Settings</li>
                        <li>Customize colors, text, and other options</li>
                        <li>Save your changes</li>
                    </ul>
                </li>
                <li><strong>Viewing Submissions:</strong>
                    <ul>
                        <li>Go to Contact Popup → Submissions</li>
                        <li>View all form submissions</li>
                        <li>Use bulk actions to manage submissions</li>
                    </ul>
                </li>
            </ol>
        </div>

        <div class="card">
            <h2>FAQ</h2>
            <p><strong>Q: How do I change the form colors?</strong></p>
            <p>A: Go to Contact Popup → Settings and use the color pickers in the Appearance Settings section.</p>

            <p><strong>Q: How do I change the email where notifications are sent?</strong></p>
            <p>A: Go to Contact Popup → Settings and update the "Notification Email" field in the Email Settings section.</p>

            <p><strong>Q: Can I customize the form fields?</strong></p>
            <p>A: Yes! Go to Contact Popup → Settings and modify the text settings for all form fields.</p>
        </div>

        <div class="card">
            <h2>Need More Help?</h2>
            <p>If you need additional support or have suggestions, please consider supporting the plugin development:</p>
            <a href="<?php echo admin_url('admin.php?page=contact-popup-donate'); ?>" class="button button-primary">Support Development</a>
        </div>
    </div>
    <?php
}


public function render_donate_page() {
    ?>
    <div class="wrap">
        <h1>Support Development</h1>
        
        <div class="card">
            <h2>Help Keep This Plugin Free and Updated</h2>
            <p>If you find this plugin useful, please consider making a small donation to support continued development and maintenance.</p>
            
            <div style="margin: 20px 0;">
                <a href="https://www.paypal.com/donate/?hosted_button_id=CJFBY7PVQGP3L" class="button button-primary button-hero" target="_blank">
                    Support via PayPal
                </a>
            </div>

            <p><strong>Your donation helps:</strong></p>
            <ul style="list-style-type: disc; margin-left: 20px;">
                <li>Keep the plugin updated and compatible with WordPress</li>
                <li>Add new features and improvements</li>
                <li>Provide support and fix bugs</li>
                <li>Create better documentation</li>
            </ul>
        </div>
    </div>
    <?php
}

// Add this method to handle the donation reminder popup
    public function add_donation_reminder() {
    // Check if it's time to show the reminder
    $last_reminder = get_option('contact_popup_donation_reminder', 0);
    $current_time = time();
    $month_in_seconds = 30 * 24 * 60 * 60;

    if ($current_time - $last_reminder >= $month_in_seconds) {
        add_action('admin_footer', array($this, 'render_donation_popup'));
        update_option('contact_popup_donation_reminder', $current_time);
    }
}

    public function render_donation_popup() {
    ?>
    <div id="donation-popup" class="donation-popup-overlay">
        <div class="donation-popup-content">
            <span class="donation-popup-close">&times;</span>
            <h2>Thank you for using Contact Popup plugin!</h2>
            <p>Funding plugins like this one with small financial contributions is essential to pay the developers to continue to do what they do. Please take a moment to give a small amount...</p>
            <div class="donation-buttons">
                <a href="https://www.paypal.com/donate/?hosted_button_id=CJFBY7PVQGP3L" class="button button-primary" target="_blank">
                    Contribute to Contact Popup
                </a>
                <button class="button donation-already-contributed">Already Contributed!</button>
            </div>
        </div>
    </div>

    <style>
    .donation-popup-overlay {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 99999;
    }

    .donation-popup-content {
        position: relative;
        background-color: #fff;
        padding: 30px;
        border-radius: 8px;
        max-width: 500px;
        width: 90%;
        margin: 50px auto;
        text-align: center;
        box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
    }

    .donation-popup-close {
        position: absolute;
        right: 15px;
        top: 10px;
        font-size: 24px;
        cursor: pointer;
        color: #666;
    }

    .donation-buttons {
        margin-top: 20px;
        display: flex;
        gap: 10px;
        justify-content: center;
    }
    </style>

    <script>
    jQuery(document).ready(function($) {
        $('#donation-popup').fadeIn();

        $('.donation-popup-close, .donation-already-contributed').on('click', function() {
            $('#donation-popup').fadeOut();
        });

        $('.donation-popup-overlay').on('click', function(e) {
            if (e.target === this) {
                $('#donation-popup').fadeOut();
            }
        });
    });
    </script>
    <?php
  }
}

// Initialize the plugin
function easy_contact_popup_init() {
    return EasyContactPopup::get_instance();
}
add_action('plugins_loaded', 'easy_contact_popup_init');

function contact_popup_create_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'contact_submissions';
    
    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE IF NOT EXISTS $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        name varchar(100) NOT NULL,
        email varchar(100) NOT NULL,
        message text NOT NULL,
        date datetime DEFAULT CURRENT_TIMESTAMP,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}
